@@ -1,4 +1,6 @@
 var webviews = require('webviews.js')
+var keybindings = require('keybindings.js')
+var PDFViewer = require('pdfViewer.js')
 
 var findinpage = {
   container: document.getElementById('findinpage-bar'),
@@ -106,3 +108,9 @@ webviews.bindEvent('found-in-page', function (webview, tabId, e, data) {
     findinpage.counter.textContent = text.replace('%i', data.activeMatchOrdinal).replace('%t', data.matches)
   }
 })
+
+keybindings.defineShortcut('followLink', function () {
+  findinpage.end({ action: 'activateSelection' })
+})
+
+module.exports = findinpage
