@@ -1,10 +1,10 @@
-const db = require('util/database.js')
+const db = require('util/database.js').db
 const places = require('places/places.js')
 
 const bookmarkStar = {
   create: function (tabId) {
     const star = document.createElement('i')
-    star.className = 'fa fa-star-o bookmarks-button' // alternative icon is fa-bookmark
+    star.className = 'fa fa-star-o tab-icon bookmarks-button' // alternative icon is fa-bookmark
 
     star.addEventListener('click', function (e) {
       bookmarkStar.onClick(tabId, star)
