@@ -1,9 +1,11 @@
 var webviews = require('webviews.js')
+var keybindings = require('keybindings.js')
 var browserUI = require('browserUI.js')
 var searchbar = require('searchbar/searchbar.js')
 var searchbarPlugins = require('searchbar/searchbarPlugins.js')
 var bangsPlugin = require('searchbar/bangsPlugin.js')
 var urlParser = require('util/urlParser.js')
+var {db} = require('util/database.js')
 
 var readerDecision = require('readerDecision.js')
 
@@ -17,10 +19,12 @@ var readerView = {
   },
   getButton: function (tabId) {
     // TODO better icon
-    var button = document.createElement('i')
-    button.className = 'fa fa-align-left reader-button'
+    var button = document.createElement('img')
+    button.className = 'reader-button tab-icon'
+    button.src = 'images/readerIcon.svg'
 
     button.setAttribute('data-tab', tabId)
+    button.setAttribute('role', 'button')
 
     button.addEventListener('click', function (e) {
       e.stopPropagation()
@@ -145,10 +149,13 @@ bangsPlugin.registerCustomBang({
 // update the reader button on page load
 
 webviews.bindEvent('did-start-navigation', function (webview, tabId, e, url, isInPlace, isMainFrame, frameProcessId, frameRoutingId) {
+  if (isInPlace) {
+    return
+  }
   if (readerDecision.shouldRedirect(url) === 1) {
     // if this URL has previously been marked as readerable, load reader view without waiting for the page to load
     readerView.enter(tabId, url)
-  } else if (isMainFrame && !isInPlace) {
+  } else if (isMainFrame) {
     tabs.update(tabId, {
       readerable: false // assume the new page can't be readered, we'll get another message if it can
     })
@@ -168,3 +175,13 @@ webviews.bindIPC('canReader', function (webview, tab) {
   })
   readerView.updateButton(tab)
 })
+
+// add a keyboard shortcut to enter reader mode
+
+keybindings.defineShortcut('toggleReaderView', function () {
+  if (readerView.isReader(tabs.getSelected())) {
+    readerView.exit(tabs.getSelected())
+  } else {
+    readerView.enter(tabs.getSelected())
+  }
+})
