@@ -40,7 +40,7 @@ var webviewMenu = {
         linkActions.push(new MenuItem({
           label: l('openInNewTab'),
           click: function () {
-            browserUI.addTab(tabs.add({ url: link }, tabs.getIndex(tabs.getSelected()) + 1), { enterEditMode: false })
+            browserUI.addTab(tabs.add({ url: link }), { enterEditMode: false })
           }
         }))
       }
@@ -48,7 +48,7 @@ var webviewMenu = {
       linkActions.push(new MenuItem({
         label: l('openInNewPrivateTab'),
         click: function () {
-          browserUI.addTab(tabs.add({ url: link, private: true }, tabs.getIndex(tabs.getSelected()) + 1), { enterEditMode: false })
+          browserUI.addTab(tabs.add({ url: link, private: true }), { enterEditMode: false })
         }
       }))
 
@@ -75,7 +75,7 @@ var webviewMenu = {
         imageActions.push(new MenuItem({
           label: l('openImageInNewTab'),
           click: function () {
-            browserUI.addTab(tabs.add({ url: image }, tabs.getIndex(tabs.getSelected()) + 1), { enterEditMode: false })
+            browserUI.addTab(tabs.add({ url: image }), { enterEditMode: false })
           }
         }))
       }
@@ -83,7 +83,7 @@ var webviewMenu = {
       imageActions.push(new MenuItem({
         label: l('openImageInNewPrivateTab'),
         click: function () {
-          browserUI.addTab(tabs.add({ url: image, private: true }, tabs.getIndex(tabs.getSelected()) + 1), { enterEditMode: false })
+          browserUI.addTab(tabs.add({ url: image, private: true }), { enterEditMode: false })
         }
       }))
 
@@ -111,7 +111,7 @@ var webviewMenu = {
             var newTab = tabs.add({
               url: searchEngine.getCurrent().searchURL.replace('%s', encodeURIComponent(selection)),
               private: currentTab.private
-            }, tabs.getIndex(tabs.getSelected()) + 1)
+            })
             browserUI.addTab(newTab, {
               enterEditMode: false
             })
